@@ -1,16 +1,21 @@
+from typing import List, Dict
+
 from botocore.exceptions import ClientError
-from prompt_toolkit import prompt
+from figcli.config.commands import promote
+
+from figcli.config.constants import SSM_STRING
 from prompt_toolkit.completion import WordCompleter
 
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.types.config import ConfigCommand
-from figcli.data.dao.ssm import SsmDao
+from figgy.data.dao.ssm import SsmDao
 from figcli.io.input import Input
-from figcli.models.run_env import RunEnv
+from figcli.io.output import Output
+from figgy.models.run_env import RunEnv
 from figcli.svcs.observability.anonymous_usage_tracker import AnonymousUsageTracker
 from figcli.svcs.observability.version_tracker import VersionTracker
 from figcli.svcs.auth.session_manager import SessionManager
-from figcli.utils.utils import *
+from figcli.utils.utils import Utils
 
 
 class Promote(ConfigCommand):
@@ -23,6 +28,7 @@ class Promote(ConfigCommand):
         self._session_mgr = session_mgr
         self._config_completer = config_completer_init
         self._utils = Utils(colors_enabled)
+        self._out = Output(colors_enabled)
 
     def _promote(self):
         repeat = True
@@ -42,12 +48,12 @@ class Promote(ConfigCommand):
                 if parameters:
                     repeat = False
                 else:
-                    print("No parameters found. Try again.\n")
+                    self._out.warn("\nNo parameters found. Try again.\n")
             except ClientError as e:
                 print(f"{self.c.fg_rd}ERROR: >> {e}{self.c.rs}")
                 continue
 
-        print(f'{self.c.fg_bl}Found {len(parameters)} parameters to migrate.{self.c.rs}\n')
+        self._out.notify(f'\nFound [[{len(parameters)}]] parameter{"s" if len(parameters) > 1 else ""} to migrate.\n')
 
         assumable_roles = self.context.defaults.assumable_roles
         matching_roles = list(set([x for x in assumable_roles if x.role == self.config_context.role]))
@@ -60,8 +66,7 @@ class Promote(ConfigCommand):
 
         for param in parameters:
             if 'KeyId' in param:
-                print(f"Skipping param: {self.c.fg_bl}{param['Name']}{self.c.rs}. "
-                      f"It is encrypted and cannot be migrated.")
+                self._out.print(f"Skipping param: [[{param['Name']}]]. It is encrypted and cannot be migrated.")
             else:
                 promote_it = Input.y_n_input(f"Would you like to promote: {param['Name']}?",
                                              default_yes=True)
@@ -70,7 +75,7 @@ class Promote(ConfigCommand):
                     val = self._source_ssm.get_parameter(param['Name'])
                     description = param.get('Description', "")
                     dest_ssm.set_parameter(param['Name'], val, description, SSM_STRING)
-                    print(f"Successfully promoted {self.c.fg_bl}{param['Name']}{self.c.rs} to {next_env}.\r\n")
+                    self._out.success(f"Successfully promoted [[{param['Name']}]] to [[{next_env}]].\r\n")
 
     @VersionTracker.notify_user
     @AnonymousUsageTracker.track_command_usage
