@@ -60,7 +60,7 @@ class ConfigFactory(Factory):
         elif command == put:
             return Put(self._ssm, self._colors_enabled, self._config_context, self._config_view, self.get(get))
         elif command == delete:
-            return Delete(self._ssm, self._config, self._config_context, self._colors_enabled,
+            return Delete(self._ssm, self._config_view, self._config, self._config_context, self._colors_enabled,
                           self._config_completer)
         elif command == get:
             return Get(self._ssm, self._config_completer, self._colors_enabled, self._config_context)
@@ -70,15 +70,15 @@ class ConfigFactory(Factory):
             return FigList(self._config_view, self._cfg_svc, self._config_completer, self._colors_enabled,
                            self._config_context, self.get(get))
         elif command == browse:
-            return Browse(self._ssm, self._colors_enabled, self._config_context, self.get(get),
+            return Browse(self._ssm, self._cfg_svc, self._colors_enabled, self._config_context, self.get(get),
                           self.get(delete), self._config_view)
         elif command == audit:
             return Audit(self._ssm, self._config, self._config_completer, self._colors_enabled, self._config_context)
         elif command == dump:
             return Dump(self._ssm, self._config_completer, self._colors_enabled, self._config_context)
         elif command == restore:
-            return Restore(self._ssm, self._kms, self._config, self._colors_enabled, self._config_context,
-                           self._config_completer, self.get(delete))
+            return Restore(self._ssm, self._kms, self._config, self._config_view, self._colors_enabled,
+                           self._config_context, self._config_completer, self.get(delete))
         elif command == promote:
             return Promote(self._ssm, self._config_completer, self._colors_enabled,
                            self._config_context, self._session_manager)
