@@ -34,7 +34,7 @@ MANUAL_HELP_TEXT = f"Migrate any K/V Hierarchy, or a single KV Pair from Consul
 IAM_HELP_TEXT = f"Manage your temporary credentials. [{CollectionUtils.printable_set(iam_commands)}]"
 ENV_HELP_TEXT = f"Valid values are:"
 INFO_HELP_TEXT = f"Prints out more detailed information about the selected subcommand."
-CONFIGURE_HELP_TEXT = f"(Optional) Setup default configurations to reduce redundant prompts."
+CONFIGURE_HELP_TEXT = f"Configure your local FiggyCLI with your remote FiggyCloud installation."
 EMPTY_ENV_HELP_TEXT = f"No --env parameter found. Using default: "
 DELETE_HELP_TEXT = f"Manually delete parameters from Parameter Store"
 LIST_HELP_TEXT = f"List, filter, and lookup parameters."
