@@ -1,6 +1,6 @@
 import pexpect
 from figcli.test.cli.config import *
-from figcli.test.cli.data.delete import DataDelete
+from figcli.test.cli.data.delete import DataDelete, DeleteAction
 from figcli.test.cli.figgy import FiggyTest
 from figcli.config import *
 from figcli.utils.utils import *
@@ -32,7 +32,7 @@ class DataPut(FiggyTest):
         self.sendline('n')
 
     def add(self, key, value, desc, add_more=False):
-        delete = DataDelete(self.extra_args)
+        delete = DeleteAction(self.extra_args)
         delete.delete(key)
         self.expect('.*Please input a PS Name.*')
         self.sendline(key)
