@@ -1,11 +1,13 @@
 import sys
 
 import pexpect
+
+from figcli.test.cli.actions.delete import DeleteAction
 from figcli.test.cli.actions.get import GetAction
 
 from figcli.test.cli.config import *
-from figcli.test.cli.data.delete import DataDelete
 from figcli.test.cli.figgy import FiggyTest
+from figcli.test.cli.test_utils import TestUtils
 from figcli.utils.utils import *
 
 
@@ -18,9 +20,9 @@ class DataSync(FiggyTest):
         self.step("Prepping workspace, deleting any existing values.")
         self.prep()
 
-        child = pexpect.spawn(f'{CLI_NAME} {Utils.get_first(config)} {Utils.get_first(sync)} '
+        child = TestUtils.spawn(f'{CLI_NAME} {Utils.get_first(config)} {Utils.get_first(sync)} '
                               f'--env {DEFAULT_ENV} --config figcli/test/assets/data_repl_conf.json '
-                              f'--skip-upgrade --replication-only {self.extra_args}', timeout=20, encoding='utf-8')
+                              f'--skip-upgrade --replication-only {self.extra_args}', timeout=30)
         time.sleep(2)
         with open('figcli/test/assets/data_repl_conf.json', 'r') as file:
             content = json.loads(file.read()).get('replicate_figs')
@@ -53,17 +55,17 @@ class DataSync(FiggyTest):
         with open('figcli/test/assets/data_repl_conf.json', 'r') as file:
             content = json.loads(file.read()).get('replicate_figs')
 
-        delete = DataDelete()
+        delete = DeleteAction()
         destinations = list(content.values())
         for i in range(0, len(destinations)):
             print(f"DELETING: {destinations[i]}")
 
             if i < len(destinations):
-                delete.delete(destinations[i], delete_another=True, repl_dest_delete=True)
+                delete.delete(destinations[i], delete_another=True)
             else:
-                delete.delete(destinations[i], delete_another=False, repl_dest_delete=True)
+                delete.delete(destinations[i], delete_another=False)
 
-        delete = DataDelete()
+        delete = DeleteAction()
         sources = list(content.keys())
         print(f"SOURCES: {sources}")
         for i in range(0, len(sources)):
